jenkins-bot has submitted this change and it was merged.

Change subject: [BREAKING CHANGE] Rename LinkInspector to 
LinkAnnotationInspector
......................................................................


[BREAKING CHANGE] Rename LinkInspector to LinkAnnotationInspector

Matches naming convention in MW. 

Bonus: Remove CSS file containing one unused rule.

Change-Id: Ied550f050b87a28fac193e54da41bc18ec1b3d71
---
M build/modules.json
M demos/ve/desktop.html
M demos/ve/mobile.html
R src/ui/inspectors/ve.ui.LinkAnnotationInspector.js
D src/ui/styles/inspectors/ve.ui.LinkInspector.css
M tests/index.html
6 files changed, 29 insertions(+), 41 deletions(-)

Approvals:
  Trevor Parscal: Looks good to me, approved
  jenkins-bot: Verified



diff --git a/build/modules.json b/build/modules.json
index 0e1cd17..2380c44 100644
--- a/build/modules.json
+++ b/build/modules.json
@@ -448,7 +448,7 @@
                        "src/ui/inspectors/ve.ui.FragmentInspector.js",
                        "src/ui/inspectors/ve.ui.AnnotationInspector.js",
                        "src/ui/inspectors/ve.ui.NodeInspector.js",
-                       "src/ui/inspectors/ve.ui.LinkInspector.js",
+                       "src/ui/inspectors/ve.ui.LinkAnnotationInspector.js",
                        "src/ui/inspectors/ve.ui.CommentInspector.js",
                        "src/ui/inspectors/ve.ui.LanguageInspector.js",
                        "src/ui/pages/ve.ui.SpecialCharacterPage.js"
@@ -481,7 +481,6 @@
                        "src/ui/styles/widgets/ve.ui.MediaSizeWidget.css",
                        "src/ui/styles/inspectors/ve.ui.CommentInspector.css",
                        "src/ui/styles/inspectors/ve.ui.FragmentInspector.css",
-                       "src/ui/styles/inspectors/ve.ui.LinkInspector.css",
                        "src/ui/styles/ve.ui.ContextItem.css",
                        
"src/ui/styles/contextitems/ve.ui.AlignableContextItem.css",
                        
"src/ui/styles/contextitems/ve.ui.CommentContextItem.css",
diff --git a/demos/ve/desktop.html b/demos/ve/desktop.html
index b7ae595..0a61d60 100644
--- a/demos/ve/desktop.html
+++ b/demos/ve/desktop.html
@@ -55,7 +55,6 @@
                <link rel=stylesheet 
href="../../src/ui/styles/widgets/ve.ui.MediaSizeWidget.css" 
class="stylesheet-ve">
                <link rel=stylesheet 
href="../../src/ui/styles/inspectors/ve.ui.CommentInspector.css" 
class="stylesheet-ve">
                <link rel=stylesheet 
href="../../src/ui/styles/inspectors/ve.ui.FragmentInspector.css" 
class="stylesheet-ve">
-               <link rel=stylesheet 
href="../../src/ui/styles/inspectors/ve.ui.LinkInspector.css" 
class="stylesheet-ve">
                <link rel=stylesheet 
href="../../src/ui/styles/ve.ui.ContextItem.css" class="stylesheet-ve">
                <link rel=stylesheet 
href="../../src/ui/styles/contextitems/ve.ui.AlignableContextItem.css" 
class="stylesheet-ve">
                <link rel=stylesheet 
href="../../src/ui/styles/contextitems/ve.ui.CommentContextItem.css" 
class="stylesheet-ve">
@@ -410,7 +409,7 @@
                <script 
src="../../src/ui/inspectors/ve.ui.FragmentInspector.js"></script>
                <script 
src="../../src/ui/inspectors/ve.ui.AnnotationInspector.js"></script>
                <script 
src="../../src/ui/inspectors/ve.ui.NodeInspector.js"></script>
-               <script 
src="../../src/ui/inspectors/ve.ui.LinkInspector.js"></script>
+               <script 
src="../../src/ui/inspectors/ve.ui.LinkAnnotationInspector.js"></script>
                <script 
src="../../src/ui/inspectors/ve.ui.CommentInspector.js"></script>
                <script 
src="../../src/ui/inspectors/ve.ui.LanguageInspector.js"></script>
                <script 
src="../../src/ui/pages/ve.ui.SpecialCharacterPage.js"></script>
diff --git a/demos/ve/mobile.html b/demos/ve/mobile.html
index 9fe1324..37ade5a 100644
--- a/demos/ve/mobile.html
+++ b/demos/ve/mobile.html
@@ -55,7 +55,6 @@
                <link rel=stylesheet 
href="../../src/ui/styles/widgets/ve.ui.MediaSizeWidget.css" 
class="stylesheet-ve">
                <link rel=stylesheet 
href="../../src/ui/styles/inspectors/ve.ui.CommentInspector.css" 
class="stylesheet-ve">
                <link rel=stylesheet 
href="../../src/ui/styles/inspectors/ve.ui.FragmentInspector.css" 
class="stylesheet-ve">
-               <link rel=stylesheet 
href="../../src/ui/styles/inspectors/ve.ui.LinkInspector.css" 
class="stylesheet-ve">
                <link rel=stylesheet 
href="../../src/ui/styles/ve.ui.ContextItem.css" class="stylesheet-ve">
                <link rel=stylesheet 
href="../../src/ui/styles/contextitems/ve.ui.AlignableContextItem.css" 
class="stylesheet-ve">
                <link rel=stylesheet 
href="../../src/ui/styles/contextitems/ve.ui.CommentContextItem.css" 
class="stylesheet-ve">
@@ -411,7 +410,7 @@
                <script 
src="../../src/ui/inspectors/ve.ui.FragmentInspector.js"></script>
                <script 
src="../../src/ui/inspectors/ve.ui.AnnotationInspector.js"></script>
                <script 
src="../../src/ui/inspectors/ve.ui.NodeInspector.js"></script>
-               <script 
src="../../src/ui/inspectors/ve.ui.LinkInspector.js"></script>
+               <script 
src="../../src/ui/inspectors/ve.ui.LinkAnnotationInspector.js"></script>
                <script 
src="../../src/ui/inspectors/ve.ui.CommentInspector.js"></script>
                <script 
src="../../src/ui/inspectors/ve.ui.LanguageInspector.js"></script>
                <script 
src="../../src/ui/pages/ve.ui.SpecialCharacterPage.js"></script>
diff --git a/src/ui/styles/inspectors/ve.ui.LinkInspector.css 
b/src/ui/styles/inspectors/ve.ui.LinkInspector.css
deleted file mode 100644
index 1147543..0000000
--- a/src/ui/styles/inspectors/ve.ui.LinkInspector.css
+++ /dev/null
@@ -1,9 +0,0 @@
-/*!
- * ObjectOriented UserInterface FragmentInspector styles.
- *
- * @copyright 2011-2015 VisualEditor Team and others; see 
http://ve.mit-license.org
- */
-
-.ve-ui-linkInspector-target {
-       width: 100%;
-}
diff --git a/tests/index.html b/tests/index.html
index e4a3cd3..7ef6c76 100644
--- a/tests/index.html
+++ b/tests/index.html
@@ -338,7 +338,7 @@
                <script 
src="../src/ui/inspectors/ve.ui.FragmentInspector.js"></script>
                <script 
src="../src/ui/inspectors/ve.ui.AnnotationInspector.js"></script>
                <script 
src="../src/ui/inspectors/ve.ui.NodeInspector.js"></script>
-               <script 
src="../src/ui/inspectors/ve.ui.LinkInspector.js"></script>
+               <script 
src="../src/ui/inspectors/ve.ui.LinkAnnotationInspector.js"></script>
                <script 
src="../src/ui/inspectors/ve.ui.CommentInspector.js"></script>
                <script 
src="../src/ui/inspectors/ve.ui.LanguageInspector.js"></script>
                <script 
src="../src/ui/pages/ve.ui.SpecialCharacterPage.js"></script>

diff --git a/src/ui/inspectors/ve.ui.LinkInspector.js 
b/src/ui/inspectors/ve.ui.LinkAnnotationInspector.js
similarity index 60%
rename from src/ui/inspectors/ve.ui.LinkInspector.js
rename to src/ui/inspectors/ve.ui.LinkAnnotationInspector.js
index ce6216f..b6df665 100644
--- a/src/ui/inspectors/ve.ui.LinkInspector.js
+++ b/src/ui/inspectors/ve.ui.LinkAnnotationInspector.js
@@ -1,5 +1,5 @@
 /*!
  * VisualEditor UserInterface LinkInspector class.
  *
  * @copyright 2011-2015 VisualEditor Team and others; see 
http://ve.mit-license.org
  */
@@ -13,24 +13,24 @@
  * @constructor
  * @param {Object} [config] Configuration options
  */
-ve.ui.LinkInspector = function VeUiLinkInspector( config ) {
+ve.ui.LinkAnnotationInspector = function VeUiLinkAnnotationInspector( config ) 
{
        // Parent constructor
        ve.ui.AnnotationInspector.call( this, config );
 };
 
 /* Inheritance */
 
-OO.inheritClass( ve.ui.LinkInspector, ve.ui.AnnotationInspector );
+OO.inheritClass( ve.ui.LinkAnnotationInspector, ve.ui.AnnotationInspector );
 
 /* Static properties */
 
-ve.ui.LinkInspector.static.name = 'link';
+ve.ui.LinkAnnotationInspector.static.name = 'link';
 
-ve.ui.LinkInspector.static.title = OO.ui.deferMsg( 
'visualeditor-linkinspector-title' );
+ve.ui.LinkAnnotationInspector.static.title = OO.ui.deferMsg( 
'visualeditor-linkinspector-title' );
 
-ve.ui.LinkInspector.static.modelClasses = [ ve.dm.LinkAnnotation ];
+ve.ui.LinkAnnotationInspector.static.modelClasses = [ ve.dm.LinkAnnotation ];
 
-ve.ui.LinkInspector.static.actions = 
ve.ui.LinkInspector.super.static.actions.concat( [
+ve.ui.LinkAnnotationInspector.static.actions = 
ve.ui.LinkAnnotationInspector.super.static.actions.concat( [
        {
                action: 'open',
                label: OO.ui.deferMsg( 'visualeditor-linkinspector-open' ),
@@ -45,14 +45,14 @@
  *
  * @param {ve.dm.LinkAnnotation} annotation New link annotation value
  */
-ve.ui.LinkInspector.prototype.onAnnotationInputChange = function () {
+ve.ui.LinkAnnotationInspector.prototype.onAnnotationInputChange = function () {
        this.updateActions();
 };
 
 /**
  * Update the actions based on the annotation state
  */
-ve.ui.LinkInspector.prototype.updateActions = function () {
+ve.ui.LinkAnnotationInspector.prototype.updateActions = function () {
        var annotation = this.annotationInput.getAnnotation(),
                href = this.annotationInput.getHref();
 
@@ -68,28 +68,28 @@
 /**
  * @inheritdoc
  */
-ve.ui.LinkInspector.prototype.shouldRemoveAnnotation = function () {
+ve.ui.LinkAnnotationInspector.prototype.shouldRemoveAnnotation = function () {
        return !this.annotationInput.getAnnotation();
 };
 
 /**
  * @inheritdoc
  */
-ve.ui.LinkInspector.prototype.getInsertionText = function () {
+ve.ui.LinkAnnotationInspector.prototype.getInsertionText = function () {
        return this.annotationInput.getHref();
 };
 
 /**
  * @inheritdoc
  */
-ve.ui.LinkInspector.prototype.getAnnotation = function () {
+ve.ui.LinkAnnotationInspector.prototype.getAnnotation = function () {
        return this.annotationInput.getAnnotation();
 };
 
 /**
  * @inheritdoc
  */
-ve.ui.LinkInspector.prototype.getAnnotationFromFragment = function ( fragment 
) {
+ve.ui.LinkAnnotationInspector.prototype.getAnnotationFromFragment = function ( 
fragment ) {
        var text = fragment.getText();
 
        return text ? new ve.dm.LinkAnnotation( {
@@ -101,9 +101,9 @@
 /**
  * @inheritdoc
  */
-ve.ui.LinkInspector.prototype.initialize = function () {
+ve.ui.LinkAnnotationInspector.prototype.initialize = function () {
        // Parent method
-       ve.ui.LinkInspector.super.prototype.initialize.call( this );
+       ve.ui.LinkAnnotationInspector.super.prototype.initialize.call( this );
 
        // Properties
        this.annotationInput = this.createAnnotationInput();
@@ -120,15 +120,15 @@
  *
  * @return {ve.ui.LinkAnnotationWidget} Link annotation widget
  */
-ve.ui.LinkInspector.prototype.createAnnotationInput = function () {
+ve.ui.LinkAnnotationInspector.prototype.createAnnotationInput = function () {
        return new ve.ui.LinkAnnotationWidget();
 };
 
 /**
  * @inheritdoc
  */
-ve.ui.LinkInspector.prototype.getSetupProcess = function ( data ) {
-       return ve.ui.LinkInspector.super.prototype.getSetupProcess.call( this, 
data )
+ve.ui.LinkAnnotationInspector.prototype.getSetupProcess = function ( data ) {
+       return 
ve.ui.LinkAnnotationInspector.super.prototype.getSetupProcess.call( this, data )
                .next( function () {
                        // Disable surface until animation is complete; will be 
reenabled in ready()
                        this.getFragment().getSurface().disable();
@@ -139,8 +139,8 @@
 /**
  * @inheritdoc
  */
-ve.ui.LinkInspector.prototype.getReadyProcess = function ( data ) {
-       return ve.ui.LinkInspector.super.prototype.getReadyProcess.call( this, 
data )
+ve.ui.LinkAnnotationInspector.prototype.getReadyProcess = function ( data ) {
+       return 
ve.ui.LinkAnnotationInspector.super.prototype.getReadyProcess.call( this, data )
                .next( function () {
                        this.annotationInput.text.focus().select();
                        this.getFragment().getSurface().enable();
@@ -156,8 +156,8 @@
 /**
  * @inheritdoc
  */
-ve.ui.LinkInspector.prototype.getHoldProcess = function ( data ) {
-       return ve.ui.LinkInspector.super.prototype.getHoldProcess.call( this, 
data )
+ve.ui.LinkAnnotationInspector.prototype.getHoldProcess = function ( data ) {
+       return 
ve.ui.LinkAnnotationInspector.super.prototype.getHoldProcess.call( this, data )
                .next( function () {
                        this.annotationInput.text.blur();
                }, this );
@@ -166,8 +166,8 @@
 /**
  * @inheritdoc
  */
-ve.ui.LinkInspector.prototype.getTeardownProcess = function ( data ) {
-       return ve.ui.LinkInspector.super.prototype.getTeardownProcess.call( 
this, data )
+ve.ui.LinkAnnotationInspector.prototype.getTeardownProcess = function ( data ) 
{
+       return 
ve.ui.LinkAnnotationInspector.super.prototype.getTeardownProcess.call( this, 
data )
                .next( function () {
                        this.annotationInput.setAnnotation( null );
                }, this );
@@ -175,4 +175,4 @@
 
 /* Registration */
 
-ve.ui.windowFactory.register( ve.ui.LinkInspector );
+ve.ui.windowFactory.register( ve.ui.LinkAnnotationInspector );
@@ -1,5 +1,5 @@
 /*!
- * VisualEditor UserInterface LinkInspector class.
+ * VisualEditor UserInterface LinkAnnotationInspector class.
  *
  * @copyright 2011-2015 VisualEditor Team and others; see 
-- 
To view, visit https://gerrit.wikimedia.org/r/209687
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: merged
Gerrit-Change-Id: Ied550f050b87a28fac193e54da41bc18ec1b3d71
Gerrit-PatchSet: 2
Gerrit-Project: VisualEditor/VisualEditor
Gerrit-Branch: master
Gerrit-Owner: Esanders <esand...@wikimedia.org>
Gerrit-Reviewer: Trevor Parscal <tpars...@wikimedia.org>
Gerrit-Reviewer: jenkins-bot <>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to